@@ -1,6 +1,6 @@
 package Sub::Spec::Pod;
 BEGIN {
-  $Sub::Spec::Pod::VERSION = '0.09';
+  $Sub::Spec::Pod::VERSION = '0.10';
 }
 # ABSTRACT: Generate POD documentation for subs
 
@@ -32,10 +32,11 @@ sub _gen_sub_pod($;$) {
     my $pod = "";
 
     die "No name in spec" unless $sub_spec->{name};
-    $pod .= "=head2 $sub_spec->{name}(\%args) -> RESP\n\n";
-
     $log->trace("Generating POD for $sub_spec->{name} ...");
 
+    $pod .= "=head2 $sub_spec->{name}(\%args) -> ".
+        "[STATUSCODE, ERRMSG, RESULT]\n\n";
+
     if ($sub_spec->{summary}) {
         $pod .= "$sub_spec->{summary}.\n\n";
     }
@@ -46,6 +47,13 @@ sub _gen_sub_pod($;$) {
         $pod .= "$desc\n\n";
     }
 
+    $pod .= <<'_';
+Returns a 3-element arrayref. STATUSCODE is 200 on success, or an error code
+between 3xx-5xx (just like in HTTP). ERRMSG is a string containing error
+message, RESULT is the actual result.
+
+_
+
     my $args  = $sub_spec->{args} // {};
     $args = { map {$_ => _parse_schema($args->{$_})} keys %$args };
     my $has_cat = grep { $_->{attr_hashes}[0]{arg_category} }
@@ -93,6 +101,19 @@ sub _gen_sub_pod($;$) {
                                if defined($ah0->{default});
             $pod .= "\n\n";
 
+            my $aliases = $ah0->{arg_aliases};
+            if ($aliases && keys %$aliases) {
+                $pod .= "Aliases: ";
+                my $i = 0;
+                for my $al (sort keys %$aliases) {
+                    $pod .= ", " if $i++;
+                    my $alinfo = $aliases->{$al};
+                    $pod .= "B<$al>".
+                        ($alinfo->{summary} ? " ($alinfo->{summary})" : "");
+                }
+                $pod .= "\n\n";
+            }
+
             $pod .= "Value must be one of:\n\n".
                 join("", map {" $_\n"} split /\n/,
                      Data::Dump::dump($ah0->{in}))."\n\n"
@@ -159,7 +180,7 @@ Sub::Spec::Pod - Generate POD documentation for subs
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -170,7 +191,7 @@ version 0.09
 This module generates API POD documentation for all subs in specified module.
 Example output:
 
- =head2 sub1(%args) -> RESP
+ =head2 sub1(%args) -> [STATUSCODE, ERRORMSG, RESULT]
 
  Summary of sub1.
 
@@ -190,7 +211,7 @@ Example output:
 
  =back
 
- =head2 sub2(%args) -> RESP
+ =head2 sub2(%args) -> [STATUSCODE, ERRMSG, RESULT]
 
  ...
 
